@@ -42,6 +42,7 @@ Guild id: {0.guild.id}
 Created at: {created_at}
 """
 
+
 class ViewInfo(View):
     def __init__(self, ctx: Context):
         super().__init__()
@@ -77,6 +78,9 @@ class ViewInfo(View):
         await interaction.response.send_message("What id/name?", ephemeral=True)
 
         message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         response = await FindSnowflake.find_user(self.bot, message.content)
         if not response:
             embed = EmbedFactory.static_embed(
@@ -94,13 +98,12 @@ class ViewInfo(View):
             description=user_info.format(
                 response,
                 joined_at=response.created_at.strftime("%m/%d/%Y"),
-                flags=', '.join([f"{k.name}" for k in response.public_flags.all()]),
-            )
+                flags=", ".join([f"{k.name}" for k in response.public_flags.all()]),
+            ),
         )
         await message.add_reaction(THUMBS_UP)
         await self.bot_message.edit(embed=embed)
 
-
     @button(label="Channel", style=ButtonStyle.green)
     async def channel_button(self, button: Button, interaction: MessageInteraction):
         embed = EmbedFactory.static_embed(
@@ -113,6 +116,9 @@ class ViewInfo(View):
         await interaction.response.send_message("What id/name?", ephemeral=True)
 
         message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         response = await FindSnowflake.find_channel(self.bot, message.content)
         if not response:
             embed = EmbedFactory.static_embed(
@@ -130,8 +136,8 @@ class ViewInfo(View):
             description=channel_info.format(
                 response,
                 created_at=response.created_at.strftime("%m/%d/%Y"),
-                invite=await self.get_invite(response)    
-            )
+                invite=await self.get_invite(response),
+            ),
         )
         await message.add_reaction(THUMBS_UP)
         await self.bot_message.edit(embed=embed)
@@ -148,6 +154,9 @@ class ViewInfo(View):
         await interaction.response.send_message("What id/name?", ephemeral=True)
 
         message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         response = await FindSnowflake.find_guild(self.bot, message.content)
         if not response:
             embed = EmbedFactory.static_embed(
@@ -170,7 +179,7 @@ class ViewInfo(View):
                 channels=len(response.text_channels),
                 roles=len(response.roles),
                 members=len([k for k in response.members if not k.bot]),
-            )
+            ),
         )
         await message.add_reaction(THUMBS_UP)
         await self.bot_message.edit(embed=embed)
@@ -187,6 +196,9 @@ class ViewInfo(View):
         await interaction.response.send_message("What id/name?", ephemeral=True)
 
         message: Message = await self.bot.wait_for("message", check=self.check)
+        if message.content == "q":
+            return await interaction.message.reply("Cancelled the current `wait_for`")
+
         response = await FindSnowflake.find_emoji(self.bot, message.content)
         if not response:
             embed = EmbedFactory.static_embed(
@@ -204,8 +216,8 @@ class ViewInfo(View):
             description=emoji_info.format(
                 response,
                 created_at=response.created_at.strftime("%m/%d/%Y"),
-            )
+            ),
         )
         embed.description += f"**Emoji:** {response}"
         await message.add_reaction(THUMBS_UP)
-        await self.bot_message.edit(embed=embed)
\ No newline at end of file
+        await self.bot_message.edit(embed=embed)
